bib\_cleaner package
====================

Submodules
----------

bib\_cleaner.bib\_cleaner module
--------------------------------

.. automodule:: bib_cleaner.bib_cleaner
   :members:
   :undoc-members:
   :show-inheritance:

bib\_cleaner.cli module
-----------------------

.. automodule:: bib_cleaner.cli
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: bib_cleaner
   :members:
   :undoc-members:
   :show-inheritance:
